<?php
/*
diskover-web
https://diskoverdata.com

Copyright 2017-2023 Diskover Data, Inc.
"Community" portion of Diskover made available under the Apache 2.0 License found here:
https://www.diskoverdata.com/apache-license/
 
All other content is subject to the Diskover Data, Inc. end user license agreement found at:
https://www.diskoverdata.com/eula-subscriptions/
  
Diskover Data products and features for all versions found here:
https://www.diskoverdata.com/solutions/

*/

require '../vendor/autoload.php';

use diskover\Constants;

error_reporting(E_ALL ^ E_NOTICE);
require "../src/diskover/Auth.php";
require "../src/diskover/Diskover.php";

$file_indexmappings = 'indexmappings.json';

// check if form has been submitted
if (isset($_POST['indexmappings'])) {
    // save the json contents
    $indexmappings = $_POST['indexmappings'];
    // check json format
    $indexmappings_arr = json_decode($indexmappings, true);
    $indexmappings_json = json_encode($indexmappings_arr, JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE | JSON_PRETTY_PRINT);
    if ($indexmappings_arr === null || $indexmappings_json === false) {
        $formerrormsg = "Json format error";
    } else {
        // update file
        file_put_contents($file_indexmappings, $indexmappings_json);
        $formsuccessmsg = "Index mappings saved. You may now close the window or go to <a href=\"settings.php\">settings</a>.";
    }
} else {
    // read the textfile
    $indexmappings = file_get_contents($file_indexmappings);
    $indexmappings_arr = json_decode($indexmappings, true);
}

?>

<!DOCTYPE html>
<html lang="en">

<head>
    <?php if (isset($_COOKIE['sendanondata']) && $_COOKIE['sendanondata'] == 1) { ?>
    <!-- Global site tag (gtag.js) - Google Analytics -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-NDFBQ1BYMH"></script>
    <script>
    window.dataLayer = window.dataLayer || [];
    function gtag(){dataLayer.push(arguments);}
    gtag('js', new Date());

    gtag('config', 'G-NDFBQ1BYMH');
    </script>
    <?php } ?>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>diskover &mdash; Edit Index Mappings</title>
    <link rel="stylesheet" href="css/fontawesome-free/css/all.min.css" media="screen" />
    <link rel="stylesheet" href="css/bootswatch.min.css" media="screen" />
    <link rel="stylesheet" href="css/diskover.css" media="screen" />
    <link rel="icon" type="image/png" href="images/diskoverfavico.png" />
</head>

<body>
    <div class="container" id="mainwindow" style="margin-top:70px;">
        <h1 class="page-header"><img src="images/diskoversmall.png" width="62" height="47" style="display:inline-block; position:relative; top:-5px"> <i class="glyphicon glyphicon-cog"></i> Edit Index Mappings</h1>
        <?php echo (!$adminuser) ? "<p><i class=\"fas fa-users-cog\"></i> <i><b>Admin user required</b></i></p>" : "" ?>
        <div class="row">
            <div class="col-lg-12">
                <div class="form-group">
                    <span class="text-info">
                        <ul>
                            <li>index_patterns key is a list of index names user/group is allowed access to view</li>
                            <li>index_patterns_exclude key is a list of index names user/group is not allowed to view</li>
                            <li>index pattern wildcards * and ? are allowed, example diskover-* or diskover-indexname-*</li>
                            <li>to not exclude any indices/dirs, use empty list [] for index_patterns_exclude, excluded_dirs, and excluded_query</li>
                            <li>excluded_dirs use absolute paths and are recursive, example /top_path/dir_name</li>
                            <li>excluded_query uses ES query string including regular expression syntax</li>
                            <li>group/user names, excluded_dirs, and excluded_query are case-sensitive</li>
                        </ul>
                    </span>
                    <form name="editindexmappings" action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" method="post" class="form-horizontal" autocorrect="off" spellcheck="false" autocapitalize="off">
                        <fieldset>
                            <div class="col-xs-12">
                                <div class="form-group">
                                    <textarea class="form-control" rows="25" name="indexmappings" style="background-color:#1C1E21;color:darkgray" <?php echo (!$adminuser) ? "disabled" : "" ?>><?php echo htmlspecialchars($indexmappings) ?></textarea>
                                    <?php if (isset($formerrormsg)) { ?>
                                        <span class="text-danger"><?php echo $formerrormsg ?></span>
                                    <?php } elseif (isset($formsuccessmsg)) { ?>
                                        <span class="text-success"><?php echo $formsuccessmsg ?></span>
                                    <?php } ?>
                                </div>
                                <div class="form-group">
                                    <button type="reset" class="btn btn-default" onclick="location.href='editindexmappings.php'" <?php echo (!$adminuser) ? "disabled" : "" ?>>Reset Changes</button>
                                    <button type="submit" class="btn btn-primary" <?php echo (!$adminuser) ? "disabled" : "" ?>>Save</button>
                                </div>
                            </div>
                        </fieldset>
                    </form>
                </div>
            </div>
        </div>

        <script language="javascript" src="js/jquery.min.js"></script>
        <script language="javascript" src="js/bootstrap.min.js"></script>
        <script language="javascript" src="js/diskover.js"></script>
</body>

</html>