<?php
/*
diskover-web
https://diskoverdata.com

Copyright 2017-2023 Diskover Data, Inc.
"Community" portion of Diskover made available under the Apache 2.0 License found here:
https://www.diskoverdata.com/apache-license/
 
All other content is subject to the Diskover Data, Inc. end user license agreement found at:
https://www.diskoverdata.com/eula-subscriptions/
  
Diskover Data products and features for all versions found here:
https://www.diskoverdata.com/solutions/

*/

require '../vendor/autoload.php';

use diskover\Constants;

error_reporting(E_ALL ^ E_NOTICE);
require "../src/diskover/Auth.php";
require "../src/diskover/Diskover.php";


// custom tags text file
$file_customtags = 'customtags.txt';

// check if form has been submitted
if (isset($_POST['tagtext'])) {
    // save the text contents
    $tagtext = $_POST['tagtext'];
    $tagtext_arr = explode("\n", $tagtext);
    // check tag format
    $dataerror = false;
    foreach ($tagtext_arr  as $tag) {
        if ($tag !== "" && strpos($tag, '|') === false) {
            $dataerror = true;
            break;
        }
    }
    if ($dataerror) {
        $formerrormsg = "Incorrect tag format, use: name|#hexcolor";
    } else {
        // update file
        // check for newline at end
        if (substr($tagtext, -1) != PHP_EOL) {
            // add newline
            $tagtext .= PHP_EOL;
        }
        file_put_contents($file_customtags, $tagtext);
        $formsuccessmsg = "Tags saved. You may now close the window or go to <a href=\"tags.php\">tags</a>.";
    }
}

// read the textfile
$tagtext = file_get_contents($file_customtags);

?>

<!DOCTYPE html>
<html lang="en">

<head>
    <?php if (isset($_COOKIE['sendanondata']) && $_COOKIE['sendanondata'] == 1) { ?>
    <!-- Global site tag (gtag.js) - Google Analytics -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=G-NDFBQ1BYMH"></script>
    <script>
    window.dataLayer = window.dataLayer || [];
    function gtag(){dataLayer.push(arguments);}
    gtag('js', new Date());

    gtag('config', 'G-NDFBQ1BYMH');
    </script>
    <?php } ?>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>diskover &mdash; Edit Tags</title>
    <link rel="stylesheet" href="css/fontawesome-free/css/all.min.css" media="screen" />
    <link rel="stylesheet" href="css/bootswatch.min.css" media="screen" />
    <link rel="stylesheet" href="css/diskover.css" media="screen" />
    <link rel="icon" type="image/png" href="images/diskoverfavico.png" />
</head>

<body>
    <div class="container" id="mainwindow" style="margin-top:70px;">
        <h1 class="page-header"><img src="images/diskoversmall.png" width="62" height="47" style="display:inline-block; position:relative; top:-5px"> <i class="glyphicon glyphicon-cog"></i> Edit Tags</h1>
        <?php echo (!$adminuser) ? "<p><i class=\"fas fa-users-cog\"></i> <i><b>Admin user required</b></i></p>" : "" ?>
        <div class="row">
            <div class="col-lg-12">
                <div class="form-group">
                    <form name="edittags" action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" method="post" class="form-horizontal" autocorrect="off" spellcheck="false" autocapitalize="off">
                        <fieldset>
                            <div class="col-xs-12">
                                <div class="form-group">
                                    <span class="text-info">
                                        <ul>
                                            <li>Format: name|html/hex color code</li>
                                            <li>Separate tag name and color with a | (pipe) character</li>
                                            <li>Separate tags with new line</li>
                                            <li>By default, tags are gray if there is no name/color below</li>
                                            <li><a href="https://htmlcolorcodes.com/" target="_blank">HTML/hex color codes</a></li>
                                        </ul>
                                    </span>
                                    <textarea class="form-control" rows="25" name="tagtext" style="background-color:#1C1E21;color:darkgray" <?php echo (!$adminuser) ? "disabled" : "" ?>><?php echo htmlspecialchars($tagtext) ?></textarea>
                                    <?php if (isset($formerrormsg)) { ?>
                                        <span class="text-danger"><?php echo $formerrormsg ?></span>
                                    <?php } elseif (isset($formsuccessmsg)) { ?>
                                        <span class="text-success"><?php echo $formsuccessmsg ?></span>
                                    <?php } ?>
                                </div>
                                <div class="form-group">
                                    <button type="reset" class="btn btn-default" onclick="location.reload()" <?php echo (!$adminuser) ? "disabled" : "" ?>>Reset Changes</button>
                                    <button type="submit" class="btn btn-primary" <?php echo (!$adminuser) ? "disabled" : "" ?>>Save Tags</button>
                                </div>
                            </div>
                        </fieldset>
                    </form>
                </div>
            </div>
        </div>

        <script language="javascript" src="js/jquery.min.js"></script>
        <script language="javascript" src="js/bootstrap.min.js"></script>
        <script language="javascript" src="js/diskover.js"></script>
</body>

</html>