<?php
/*
diskover-web
https://diskoverdata.com

Copyright 2017-2023 Diskover Data, Inc.
"Community" portion of Diskover made available under the Apache 2.0 License found here:
https://www.diskoverdata.com/apache-license/
 
All other content is subject to the Diskover Data, Inc. end user license agreement found at:
https://www.diskoverdata.com/eula-subscriptions/
  
Diskover Data products and features for all versions found here:
https://www.diskoverdata.com/solutions/

*/

// diskover-web sqlite3 api user database

namespace diskover;
use SQLite3;

class ApiUserDatabase
{
    private $db;
    private $databaseFilename;

    public function connect()
    {
        require 'config_inc.php';
        // Get datbase file path from config
        $this->databaseFilename = $config->DATABASE;

        // Open sqlite database
        $this->db = new SQLite3($this->databaseFilename);

        // Initial setup if necessary.
        $this->setupDatabase();
    }

    protected function setupDatabase()
    {
        require 'config_inc.php';
        // If the database apiusers table exists we have nothing to do here.
        $res = $this->db->query("SELECT name FROM sqlite_master WHERE type='table' AND name='apiusers'");
        if ($row = $res->fetchArray()) {
            return;
        }

        // Set up sqlite user table if does not yet exist.
        $this->db->exec("CREATE TABLE IF NOT EXISTS apiusers (
            id INTEGER PRIMARY KEY AUTOINCREMENT, 
            username TEXT NOT NULL, 
            password TEXT NOT NULL
        )");

        // Grab config data and create initial user.
        $user = new User();
        $user->username = $config->API_USER;
        $user->setPassword($config->API_PASS);

        // Add the user, and save the newly created entry.
        $this->addUser($user);
    }

    protected function addUser(User $user)
    {
        $this->db->exec("INSERT INTO apiusers ('username', 'password') 
            VALUES ('$user->username', '$user->passHash')");
    }

    protected function closeDatabase()
    {
        $this->db->close();
    }

    public function findUser($username): User
    {
        $user = new User();

        $res = $this->db->query('SELECT * FROM apiusers');

        while ($row = $res->fetchArray()) {
            if ($row['username'] != $username) {
                continue;
            }

            // Found a username match.
            $user->isValid = true;
            $user->username = $row['username'];
            $user->passHash = $row['password'];
        }

        return $user;
    }

    public function changePassword(bool $initialChange): string
    {
        require 'config_inc.php';
        $username = $config->API_USER;
        $password1 = $_POST['apipassword'];
        $password2 = $_POST['apipassword2'];
        $currentPassword = $_POST['apipasswordCurrent'];

        $user = $this->findUser($username);
        if (!$user->isValid) {
            // This should not happen unless something strange
            // causes the user database to be missing the currently
            // logged in $_SESSION['username']
            return 'Error, could not find current user.';
        }

        // On their initial password set, we will not prompt them
        // for a password, but for sanity, make sure the current
        // password matches the expected default password.
        if ($initialChange) {
            if (!$user->validatePassword($config->API_PASS)) {
                // They were attempting to change their password from the
                // initial password change page, but the database password
                // does not match the expected default password.
                return 'Initial API password has already been set.';
            }
        } else {
            // This is not the initial password change, so validate
            // against the password in the database.
            if (!$user->validatePassword($currentPassword)) {
                return 'Current API password is not correct.';
            }
        }

        // Ensure passwords match, then we can work on one variable.
        if ($password1 !== $password2) {
            return 'API Passwords do not match.';
        }

        // Ensure password not same as default.
        if ($password1 === $config->API_PASS) {
            return 'API Password same as default, use a different password.';
        }

        // Consider additional complexity requirements.
        // For now, at least 8 characters.
        if (strlen($password1) < 8) {
            return 'API Password should be 8 characters or longer.';
        }

        // Update the password.
        $user->setPassword($password1);
        try {
            // Persist and save.
            $this->updateUser($user);
            //$this->closeDatabase();
        } catch(\Exception $e) {
            // This should not happen since the user was checked above.
            return 'Error, failed to find and update user.';
        }

        // Successful, no error.
        return '';
    }

    /**
     * Does not support changing username.
     * Only update is password hash.
     *
     * @throws \Exception
     */
    public function updateUser(User $user)
    {
        $foundUser = false;

        $res = $this->db->exec("UPDATE apiusers SET password='$user->passHash' WHERE username = '$user->username'");

        if ($res) {
            $foundUser = true;
        }

        if (!$foundUser) {
            throw new \Exception('Tried to update a non-existent user.');
        }
    }
}
